@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -204,7 +202,7 @@
      BACKQUOTELPAREN = 420,
      COMMALPAREN = 421,
      PERCENTLPAREN = 422,
-     DLRARRSZ = 423,
+     DLRARRPSZ = 423,
      DLRLST_T = 424,
      DLRLST_VT = 425,
      DLRREC_T = 426,
