@@ -58,7 +58,7 @@
 /* ****** ****** */
 //
 // HX-2011-04-24: the function [alloca] is declared in
-extern void *alloca (size_t nsz) ; // [alloca.h] or [stdlib.h]
+extern void *alloca (size_t bsz) ; // [alloca.h] or [stdlib.h]
 
 /* ****** ****** */
 
