@@ -96,14 +96,34 @@ ats_exn_type
 DivisionByZeroExceptionCon = { 30, "DivisionByZeroException" } ;
 ats_exn_ptr_type DivisionByZeroException = &DivisionByZeroExceptionCon ;
 
+/* ****** ****** */
+
 ats_exn_type
-SubscriptExceptionCon = { 40, "SubscriptException" } ;
-ats_exn_ptr_type SubscriptException = &SubscriptExceptionCon ;
+ListSubscriptExceptionCon = { 40, "ListSubscriptException" } ;
+ats_exn_ptr_type ListSubscriptException = &ListSubscriptExceptionCon ;
+ats_exn_ptr_type
+ListSubscriptException_make () { return ListSubscriptException ; }
+ats_bool_type
+isListSubscriptException (ats_exn_ptr_type exn) {
+  return (ListSubscriptException->tag==exn->tag ? ats_true_bool : ats_false_bool) ;
+}
+
+ats_exn_type
+ArraySubscriptExceptionCon = { 50, "ArraySubscriptException" } ;
+ats_exn_ptr_type ArraySubscriptException = &ArraySubscriptExceptionCon ;
+ats_exn_ptr_type
+ArraySubscriptException_make () { return ArraySubscriptException ; }
+ats_bool_type
+isArraySubscriptException (ats_exn_ptr_type exn) {
+  return (ArraySubscriptException->tag==exn->tag ? ats_true_bool : ats_false_bool) ;
+}
 
 /* ****** ****** */
 //
-// HX: the numbers less than 1000 are all
-int ats_exception_con_tag = 1000 ; // reserved for special use
+// HX: the numbers less than 1024 are all
+int ats_exception_con_tag = 1024 ; // reserved for special use
+
+/* ****** ****** */
 
 /*
 ** function for handling uncaught exceptions
